==> open-xchange-mobile-push-plugin_1.0.0.orig.tar.bz2: open-xchange-mobile-push-plugin-1.0.0/com.openexchange.mobilepush.events.storage/src/com/openexchange/mobilepush/events/storage/Subscription.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobilepush.events.storage;

import com.openexchange.mobilepush.MobilePushProviders;

/**
 * {@link Subscription}
 *
 * @author <a href="mailto:lars.hoogestraat@open-xchange.com">Lars Hoogestraat</a>
 */
public class Subscription {
    private int contextId;
    private int userId;
    private String token;
    private String serviceId;
    private MobilePushProviders mobileNotifierProviders;
    private long timestamp;

    public Subscription() {
        super();
    }

    public Subscription(int contextId, int userId, String token, String serviceId, MobilePushProviders mobileNotifierProviders, long timestamp) {
        this.contextId = contextId;
        this.userId = userId;
        this.token = token;
        this.serviceId = serviceId;
        this.mobileNotifierProviders = mobileNotifierProviders;
        this.timestamp = timestamp;
    }

    public int getContextId() {
        return contextId;
    }

    public void setContextId(int contextId) {
        this.contextId = contextId;
    }

    public int getUserId() {
        return userId;
    }

    public void setUserId(int userId) {
        this.userId = userId;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getServiceId() {
        return serviceId;
    }

    public void setServiceId(String serviceId) {
        this.serviceId = serviceId;
    }

    public MobilePushProviders getProvider() {
        return mobileNotifierProviders;
    }

    public String getProviderName() {
        return mobileNotifierProviders.getProviderName();
    }

    public void setMobileNotifierProviders(MobilePushProviders mobileNotifierProviders) {
        this.mobileNotifierProviders = mobileNotifierProviders;
    }

    public long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(long timestamp) {
        this.timestamp = timestamp;
    }

    @Override
    public String toString() {
        return "Subscription [contextId=" + contextId + ", userId=" + userId + ", token=" + token + ", serviceId=" + serviceId + ", mobileNotifierProviders=" + mobileNotifierProviders.getProviderName() + ", timestamp=" + timestamp + "]";
    }
}

==> open-xchange-mobile-push-plugin_1.4.0.orig.tar.bz2: open-xchange-mobile-push-plugin-1.4.0/com.openexchange.mobilepush.events.storage/src/com/openexchange/mobilepush/events/storage/Subscription.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobilepush.events.storage;

import com.openexchange.mobilepush.MobilePushProvider;

/**
 * {@link Subscription}
 *
 * @author <a href="mailto:lars.hoogestraat@open-xchange.com">Lars Hoogestraat</a>
 */
public class Subscription {
    private int contextId;
    private int userId;
    private String token;
    private String serviceId;
    private MobilePushProvider mobileNotifierProviders;
    private long timestamp;

    public Subscription() {
        super();
    }

    public Subscription(int contextId, int userId, String token, String serviceId, MobilePushProvider mobileNotifierProviders, long timestamp) {
        this.contextId = contextId;
        this.userId = userId;
        this.token = token;
        this.serviceId = serviceId;
        this.mobileNotifierProviders = mobileNotifierProviders;
        this.timestamp = timestamp;
    }

    public int getContextId() {
        return contextId;
    }

    public void setContextId(int contextId) {
        this.contextId = contextId;
    }

    public int getUserId() {
        return userId;
    }

    public void setUserId(int userId) {
        this.userId = userId;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getServiceId() {
        return serviceId;
    }

    public void setServiceId(String serviceId) {
        this.serviceId = serviceId;
    }

    public MobilePushProvider getProvider() {
        return mobileNotifierProviders;
    }

    public String getProviderName() {
        return mobileNotifierProviders.getProviderName();
    }

    public void setMobileNotifierProviders(MobilePushProvider mobileNotifierProviders) {
        this.mobileNotifierProviders = mobileNotifierProviders;
    }

    public long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(long timestamp) {
        this.timestamp = timestamp;
    }

    @Override
    public String toString() {
        return "Subscription [contextId=" + contextId + ", userId=" + userId + ", token=" + token + ", serviceId=" + serviceId + ", mobileNotifierProviders=" + mobileNotifierProviders.getProviderName() + ", timestamp=" + timestamp + "]";
    }
}
